import permissionmessages_pb2 as _permissionmessages_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class _GenerateApiTokenRequest(_message.Message):
    __slots__ = ["auth_token", "description", "expires", "never", "permissions", "token_id"]
    class Expires(_message.Message):
        __slots__ = ["valid_for_seconds"]
        VALID_FOR_SECONDS_FIELD_NUMBER: _ClassVar[int]
        valid_for_seconds: int
        def __init__(self, valid_for_seconds: _Optional[int] = ...) -> None: ...
    class Never(_message.Message):
        __slots__ = []
        def __init__(self) -> None: ...
    AUTH_TOKEN_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    EXPIRES_FIELD_NUMBER: _ClassVar[int]
    NEVER_FIELD_NUMBER: _ClassVar[int]
    PERMISSIONS_FIELD_NUMBER: _ClassVar[int]
    TOKEN_ID_FIELD_NUMBER: _ClassVar[int]
    auth_token: str
    description: str
    expires: _GenerateApiTokenRequest.Expires
    never: _GenerateApiTokenRequest.Never
    permissions: _permissionmessages_pb2.Permissions
    token_id: str
    def __init__(self, never: _Optional[_Union[_GenerateApiTokenRequest.Never, _Mapping]] = ..., expires: _Optional[_Union[_GenerateApiTokenRequest.Expires, _Mapping]] = ..., auth_token: _Optional[str] = ..., permissions: _Optional[_Union[_permissionmessages_pb2.Permissions, _Mapping]] = ..., token_id: _Optional[str] = ..., description: _Optional[str] = ...) -> None: ...

class _GenerateApiTokenResponse(_message.Message):
    __slots__ = ["api_key", "endpoint", "refresh_token", "valid_until"]
    API_KEY_FIELD_NUMBER: _ClassVar[int]
    ENDPOINT_FIELD_NUMBER: _ClassVar[int]
    REFRESH_TOKEN_FIELD_NUMBER: _ClassVar[int]
    VALID_UNTIL_FIELD_NUMBER: _ClassVar[int]
    api_key: str
    endpoint: str
    refresh_token: str
    valid_until: int
    def __init__(self, api_key: _Optional[str] = ..., refresh_token: _Optional[str] = ..., endpoint: _Optional[str] = ..., valid_until: _Optional[int] = ...) -> None: ...

class _LoginRequest(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class _LoginResponse(_message.Message):
    __slots__ = ["direct_browser", "error", "logged_in", "message"]
    class DirectBrowser(_message.Message):
        __slots__ = ["url"]
        URL_FIELD_NUMBER: _ClassVar[int]
        url: str
        def __init__(self, url: _Optional[str] = ...) -> None: ...
    class Error(_message.Message):
        __slots__ = ["description"]
        DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
        description: str
        def __init__(self, description: _Optional[str] = ...) -> None: ...
    class LoggedIn(_message.Message):
        __slots__ = ["session_token", "valid_for_seconds"]
        SESSION_TOKEN_FIELD_NUMBER: _ClassVar[int]
        VALID_FOR_SECONDS_FIELD_NUMBER: _ClassVar[int]
        session_token: str
        valid_for_seconds: int
        def __init__(self, session_token: _Optional[str] = ..., valid_for_seconds: _Optional[int] = ...) -> None: ...
    class Message(_message.Message):
        __slots__ = ["text"]
        TEXT_FIELD_NUMBER: _ClassVar[int]
        text: str
        def __init__(self, text: _Optional[str] = ...) -> None: ...
    DIRECT_BROWSER_FIELD_NUMBER: _ClassVar[int]
    ERROR_FIELD_NUMBER: _ClassVar[int]
    LOGGED_IN_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    direct_browser: _LoginResponse.DirectBrowser
    error: _LoginResponse.Error
    logged_in: _LoginResponse.LoggedIn
    message: _LoginResponse.Message
    def __init__(self, direct_browser: _Optional[_Union[_LoginResponse.DirectBrowser, _Mapping]] = ..., logged_in: _Optional[_Union[_LoginResponse.LoggedIn, _Mapping]] = ..., message: _Optional[_Union[_LoginResponse.Message, _Mapping]] = ..., error: _Optional[_Union[_LoginResponse.Error, _Mapping]] = ...) -> None: ...

class _RefreshApiTokenRequest(_message.Message):
    __slots__ = ["api_key", "refresh_token"]
    API_KEY_FIELD_NUMBER: _ClassVar[int]
    REFRESH_TOKEN_FIELD_NUMBER: _ClassVar[int]
    api_key: str
    refresh_token: str
    def __init__(self, api_key: _Optional[str] = ..., refresh_token: _Optional[str] = ...) -> None: ...

class _RefreshApiTokenResponse(_message.Message):
    __slots__ = ["api_key", "endpoint", "refresh_token", "valid_until"]
    API_KEY_FIELD_NUMBER: _ClassVar[int]
    ENDPOINT_FIELD_NUMBER: _ClassVar[int]
    REFRESH_TOKEN_FIELD_NUMBER: _ClassVar[int]
    VALID_UNTIL_FIELD_NUMBER: _ClassVar[int]
    api_key: str
    endpoint: str
    refresh_token: str
    valid_until: int
    def __init__(self, api_key: _Optional[str] = ..., refresh_token: _Optional[str] = ..., endpoint: _Optional[str] = ..., valid_until: _Optional[int] = ...) -> None: ...



import common_pb2 as _common_pb2
import extensions_pb2 as _extensions_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class _Discontinuity(_message.Message):
    __slots__ = ["last_topic_sequence", "new_topic_sequence"]
    LAST_TOPIC_SEQUENCE_FIELD_NUMBER: _ClassVar[int]
    NEW_TOPIC_SEQUENCE_FIELD_NUMBER: _ClassVar[int]
    last_topic_sequence: int
    new_topic_sequence: int
    def __init__(self, last_topic_sequence: _Optional[int] = ..., new_topic_sequence: _Optional[int] = ...) -> None: ...

class _Heartbeat(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class _PublishRequest(_message.Message):
    __slots__ = ["cache_name", "topic", "value"]
    CACHE_NAME_FIELD_NUMBER: _ClassVar[int]
    TOPIC_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    cache_name: str
    topic: str
    value: _TopicValue
    def __init__(self, cache_name: _Optional[str] = ..., topic: _Optional[str] = ..., value: _Optional[_Union[_TopicValue, _Mapping]] = ...) -> None: ...

class _SubscriptionItem(_message.Message):
    __slots__ = ["discontinuity", "heartbeat", "item"]
    DISCONTINUITY_FIELD_NUMBER: _ClassVar[int]
    HEARTBEAT_FIELD_NUMBER: _ClassVar[int]
    ITEM_FIELD_NUMBER: _ClassVar[int]
    discontinuity: _Discontinuity
    heartbeat: _Heartbeat
    item: _TopicItem
    def __init__(self, item: _Optional[_Union[_TopicItem, _Mapping]] = ..., discontinuity: _Optional[_Union[_Discontinuity, _Mapping]] = ..., heartbeat: _Optional[_Union[_Heartbeat, _Mapping]] = ...) -> None: ...

class _SubscriptionRequest(_message.Message):
    __slots__ = ["cache_name", "resume_at_topic_sequence_number", "topic"]
    CACHE_NAME_FIELD_NUMBER: _ClassVar[int]
    RESUME_AT_TOPIC_SEQUENCE_NUMBER_FIELD_NUMBER: _ClassVar[int]
    TOPIC_FIELD_NUMBER: _ClassVar[int]
    cache_name: str
    resume_at_topic_sequence_number: int
    topic: str
    def __init__(self, cache_name: _Optional[str] = ..., topic: _Optional[str] = ..., resume_at_topic_sequence_number: _Optional[int] = ...) -> None: ...

class _TopicItem(_message.Message):
    __slots__ = ["publisher_id", "topic_sequence_number", "value"]
    PUBLISHER_ID_FIELD_NUMBER: _ClassVar[int]
    TOPIC_SEQUENCE_NUMBER_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    publisher_id: str
    topic_sequence_number: int
    value: _TopicValue
    def __init__(self, topic_sequence_number: _Optional[int] = ..., value: _Optional[_Union[_TopicValue, _Mapping]] = ..., publisher_id: _Optional[str] = ...) -> None: ...

class _TopicValue(_message.Message):
    __slots__ = ["binary", "text"]
    BINARY_FIELD_NUMBER: _ClassVar[int]
    TEXT_FIELD_NUMBER: _ClassVar[int]
    binary: bytes
    text: str
    def __init__(self, text: _Optional[str] = ..., binary: _Optional[bytes] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: token.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import permissionmessages_pb2 as permissionmessages__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0btoken.proto\x12\x05token\x1a\x18permissionmessages.proto\"\xe5\x01\n\x1f_GenerateDisposableTokenRequest\x12?\n\x07\x65xpires\x18\x01 \x01(\x0b\x32..token._GenerateDisposableTokenRequest.Expires\x12\x12\n\nauth_token\x18\x02 \x01(\t\x12\x35\n\x0bpermissions\x18\x03 \x01(\x0b\x32 .permission_messages.Permissions\x12\x10\n\x08token_id\x18\x04 \x01(\t\x1a$\n\x07\x45xpires\x12\x19\n\x11valid_for_seconds\x18\x01 \x01(\r\"Z\n _GenerateDisposableTokenResponse\x12\x0f\n\x07\x61pi_key\x18\x01 \x01(\t\x12\x10\n\x08\x65ndpoint\x18\x02 \x01(\t\x12\x13\n\x0bvalid_until\x18\x03 \x01(\x04\x32u\n\x05Token\x12l\n\x17GenerateDisposableToken\x12&.token._GenerateDisposableTokenRequest\x1a\'.token._GenerateDisposableTokenResponse\"\x00\x42`\n\rmomento.tokenP\x01Z0github.com/momentohq/client-sdk-go;client_sdk_go\xaa\x02\x1aMomento.Protos.TokenClientb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'token_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\rmomento.tokenP\001Z0github.com/momentohq/client-sdk-go;client_sdk_go\252\002\032Momento.Protos.TokenClient'
  __GENERATEDISPOSABLETOKENREQUEST._serialized_start=49
  __GENERATEDISPOSABLETOKENREQUEST._serialized_end=278
  __GENERATEDISPOSABLETOKENREQUEST_EXPIRES._serialized_start=242
  __GENERATEDISPOSABLETOKENREQUEST_EXPIRES._serialized_end=278
  __GENERATEDISPOSABLETOKENRESPONSE._serialized_start=280
  __GENERATEDISPOSABLETOKENRESPONSE._serialized_end=370
  _TOKEN._serialized_start=372
  _TOKEN._serialized_end=489
# @@protoc_insertion_point(module_scope)
